---
description: This page outlines how Launchable interfaces with Android Debug Bridge (adb).
---

# Android Debug Bridge (adb)

Launchable interfaces with adb via the Launchable CLI.

See [recording-test-results-with-the-launchable-cli](../../sending-data-to-launchable/using-the-launchable-cli/recording-test-results-with-the-launchable-cli/ "mention") and [subsetting-with-the-launchable-cli](../../features/predictive-test-selection/requesting-and-running-a-subset-of-tests/subsetting-with-the-launchable-cli/ "mention") for more information.
